#
# spec file for package python-libnacl
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?sle15_python_module_pythons}
Name:           python-libnacl
Version:        2.1.0
Release:        2.1
Summary:        Python bindings for libsodium based on ctypes
License:        Apache-2.0
URL:            https://github.com/saltstack/libnacl
Source0:        https://github.com/saltstack/libnacl/archive/v%{version}.tar.gz#/libnacl-%{version}.tar.gz
BuildRequires:  %{python_module devel}
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module poetry}
BuildRequires:  %{python_module wheel}
BuildRequires:  fdupes
BuildRequires:  pkgconfig
BuildRequires:  python-rpm-macros
BuildRequires:  pkgconfig(libsodium)
# This will need updating and verification but smart magic is not copied by
#  singlespec macros
Requires:       libsodium26
BuildArch:      noarch
%python_subpackages

%description
This library is used to gain direct access to the functions exposed by Daniel J. Bernstein's nacl library via libsodium.
It has been constructed to maintain extensive documentation on how to use nacl as well as being completely portable. The file
in libnacl/__init__.py can be pulled out and placed directly in any project to give a single file binding to all of nacl.

%prep
%autosetup -p1 -n libnacl-%{version}

%build
%pyproject_wheel

%install
%pyproject_install
%python_expand %fdupes %{buildroot}/%{$python_sitelib}

%check
%python_expand $python tests/runtests.py

%files %{python_files}
%license LICENSE
%doc README.rst
%{python_sitelib}/libnacl
%{python_sitelib}/libnacl-%{version}.dist-info

%changelog
* Wed Jun 12 2024 Dirk Müller <dmueller@suse.com>
- update to libsodium26
* Fri Mar  1 2024 Steve Kowalik <steven.kowalik@suse.com>
- Update to 2.1.0:
  * Added classes to the libnacl.aead module allowing for the use of
    XChaCha20-Poly1305-IETF, ChaCha20-Poly1305-IETF, and AES256-GCM.
  * Added the libnacl.kx module. This module contains the ExchangeKey class.
- Switch to autosetup and pyproject macros.
- Drop patch crypto_kdf_derive.patch, no longer required.
* Wed Jul  5 2023 ecsos <ecsos@opensuse.org>
- Add %%{?sle15_python_module_pythons}
* Fri Jun 11 2021 Niels Abspoel <aboe76@gmail.com>
- add crypto_kdf_derive.patch to fix crypto_kdf_derive_from_key() on 32-bit platforms
* Thu Feb 18 2021 Niels Abspoel <aboe76@gmail.com>
- Revert libsodium requirement back to libsodium23
* Mon Feb  1 2021 Niels Abspoel <aboe76@gmail.com>
- Update to 1.7.2
  * remove encoding parameter json.loads for python 3.9 compatibility
  * implement functions for equal-comparison and hashing keys
  * improved spec file
* Tue Mar  3 2020 Ondřej Súkup <mimi.vx@gmail.com>
- update to 1.7.1
  * Bindings for kdf in libsodium
  * Added extra key validation
  * Add Crypto_box_easy
* Mon Oct 14 2019 Matej Cepl <mcepl@suse.com>
- Replace %%fdupes -s with plain %%fdupes; hardlinks are better.
* Fri Aug 10 2018 tchvatal@suse.com
- Fix the libsodium dependency on the runtime to be copied by macros
- Install license file
* Fri Dec 22 2017 adrian@suse.de
- update to version 1.6.1 from github
- drop obsolete patch libnacl-1.4.4-libsodium18.patch
- enable python3 builds
* Wed Apr 13 2016 zaitor@opensuse.org
- Add conditional pkgconfig(libsodium) BuildRequires for all
  openSUSE versions newer than 13.1.
* Thu Jan 14 2016 dmacvicar@suse.de
- remove the escaped epoch to prevent the build service to
  auto replace it and break the macro.
* Thu Jan 14 2016 dmacvicar@suse.de
- Add libnacl-1.4.4-libsodium18.patch to find libsodium 1.0.8
- Fix BuildRequires to avoid building with a newer version
  of libsodium than 1.0.8
* Mon Jan  4 2016 aboe76@gmail.com
- Updated to 1.4.4
  - Add pack_nonce options to secretbox
    libnacl secretbox has been packing the nonce in each message,
    the new pack_nonce option allows for the nonce to be omitted
    which allows for more flexible options
  - Add soversion 17 detection
    Added explicit soversion support for libsodium 17
  - Fix crypto_onetimeauth tests
    The crypto onetimeauth test issues have been resolved
  - Remove tweetnacl Support
    The tweetnacl support was never really tested, and since the
    tweetnacl api is not complete we have removed support for it
  - Add sodium_init calls
    Added calls to sodium_init when the lib is loaded
  - packaging:
  - New BuildRequirement python-setuptools
  - Updated the description
  - Removed the patch for soname: libnacl-1.4.3_bump_libsodium_soversion.patch
    not needed anymore
* Thu Nov 19 2015 mrueckert@suse.de
- no longer build as noarch package, while the code is still
  noarch. we actually depend on the native library at runtime. To
  be able to make this work properly we need to require that native
  library, that native requires makes us arch dependent.
* Thu Nov 19 2015 mrueckert@suse.de
- make sure we require the libsodium version we were built with
* Thu Nov 19 2015 mrueckert@suse.de
- fix libsodium loading on Tumbleweed: soversion was bumped to 17
  reported as https://github.com/saltstack/libnacl/pull/60
  adds libnacl-1.4.3_bump_libsodium_soversion.patch
* Thu Jun 11 2015 aboe76@gmail.com
- Updated to 1.4.3
- crypto_onetimeauth_verify fixes
  + Fix a call to the crypto_onetimeauth_verify routine into the right libsodium system
  + Add tests for crypto_onetimeauth_verify
- Add support for reading file streams for key loading
* Tue Mar 17 2015 aboe76@gmail.com
- Updated to 1.4.2
  + Add support to save and load SecretBox keys
* Thu Feb 19 2015 aboe76@gmail.com
- Updated to 1.4.1
  + Fix for crypto_auth_verify and crypto_auth_onetimeverify
  + Lint fixes and updates
* Mon Nov  3 2014 aboe76@gmail.com
- Updated to 1.4.0
  + Initial support has been added for the blake2b hash algorithm
  + Fix issue with keyfile saves on windows
  + Fix libsodium detection for Ubuntu manual installs and Windows dll detection
* Thu Oct  2 2014 aboe76@gmail.com
- Small update to 1.3.6
  + Restrict library load to specific supported libsodium versions
  + fix randombytes functions
* Tue Sep  9 2014 aboe76@gmail.com
- Updated to 1.3.5
  + only updates for py3
* Tue Sep  2 2014 aboe76@gmail.com
- Updated to 1.3.4
  + Fixed issue and add tests for bug where saving and loading a signing key caused a stack trace, se issue #18
  + Change the default ctype values to be more accurate and efficient
  + Update soname detection on Linux for libsodium 0.7.0
  + Make soname detection a little more future proof
* Thu Aug 14 2014 aboe76@gmail.com
- Updated to 1.3.2:
  + Add detection of the libsodium.so.10 lib created by libsodium 0.6
* Wed Jul 30 2014 aboe76@gmail.com
- Updated to 1.2.0
  his release introduces the DualKey class, secure key saving and loading,
  as well as enhancements to the time_nonce function.
  Dual Key Class
  Dual Keys are classes which can encrypt and sign data. These classes generate
  and maintain both Curve25519 and Ed25519 keys, as well as all methods for both encryption and signing.
  Time Nonce Improvements
  The original time nonce routine used the first 20 chars of the 24 char nonce for the microsecond
  timestamp (based on salt's jid), leaving 4 chars for random data. This new nonce uses far fewer
  chars for the timestamp by hex encoding the float of microseconds into just 13 chars,
  leaving 11 chars of random data. This makes the default nonce safer and more secure.on.
* Wed Jul  2 2014 aboe76@gmail.com
- Updated to 1.1.0
* Fri Jun 20 2014 aboe76@gmail.com
- Simplified BuildRequirements to libsodium-devel
* Mon Jun  9 2014 aboe76@gmail.com
- initial package
